@@ -194,3 +194,8 @@ class KeystoneUnauthorized(IronicException):
 
 class KeystoneFailure(IronicException):
     pass
+
+
+class MetricsNotSupported(IronicException):
+    _msg_fmt = _("Metrics action is not supported. You may need to "
+                 "adjust the [metrics] section in ironic.conf.")
